require(ggplot2)
library(RColorBrewer)
library(scales)
require(reshape2)
require(dplyr)
require(Hmisc)

filenames <- list.files(path=".",pattern="Fig3E-F\\.input$")
names <-gsub(".txt","",filenames)
length(names)

for(i in 1:length(names)){
  for (N in c(20)){
  filepath<-filenames[i]
  df<-read.table(filepath,
                 col.names =c('Gene','Length','H3K27me3_promoter','H3K27me3_genebody','PromoterK27','GenebodyK27','IndexK27','PromoterPolII','GenebodyPolII','IndexPolII'),
                 sep = "\t")
  df<-df[order(-df$IndexK27),]
  dfs=df[df[["H3K27me3_genebody"]]>0 & df[["H3K27me3_promoter"]]>0 & df[["PromoterK27"]]>0.01 & df[["GenebodyK27"]]>0.01 & df[["GenebodyPolII"]]>0.01 & df[["PromoterPolII"]]>0.01,]
  dfs1 <- dfs%>%
    group_by(IndexK27_bin = as.numeric(cut2(IndexK27, g=N)))
  dfs2<-dfs1 %>%
    summarise(
      count=n(),
      Length=mean(Length),
      K27_length_P=mean(H3K27me3_promoter),
      K27_length_G=mean(H3K27me3_genebody),
      K27_P=mean(PromoterK27),
      K27_G=mean(GenebodyK27),
      K27_I=mean(IndexK27),
      PolII_P=mean(PromoterPolII),
      PolII_G=mean(GenebodyPolII),
      PolII_I=mean(IndexPolII)
    )
  for (p in c(8)){
  dfs3<-filter(dfs1,IndexK27_bin==1 | IndexK27_bin==p | IndexK27_bin==10)
  
  id="boxplot"
  
  feature=paste(names(dfs1)[7],names(dfs1)[10],id,N,sep=".")
  ggplot(dfs3,aes(x=as.factor(IndexK27_bin),y=log2(IndexPolII),color=as.factor(IndexK27_bin)))+
    stat_boxplot(geom = "errorbar", width = 0.3,lwd=0.6,coef=0.8)+
    geom_boxplot(outlier.shape = NA, coef=0.8,lwd=0.6,width = 0.5)+
    scale_y_continuous(limits = quantile(log2(dfs$IndexPolII), c(0.02, 0.99)))+
    theme_bw()+
    scale_color_manual(breaks=c("1","8","10"),
                      labels=c("Low_indexK27","Control","High_indexK27"),
                      values=c('blue','grey','red'))+
    theme(panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(),
          axis.text.y = element_text(size =rel(2) ),
          axis.text.x=element_blank(),
          axis.title.x=element_blank(),
          axis.title.y=element_blank(),
          legend.title=element_blank(),
          legend.key = element_blank(),
          legend.position="none")
  output=paste("Fig.3F","pdf",sep=".")
  print (output)
  print (c('gene number',dfs2[[2,2]]))
  print (c('low vs. control:',p,wilcox.test(x=dfs3$IndexPolII[dfs3$IndexK27_bin==1],y=dfs3$IndexPolII[dfs3$IndexK27_bin==p],alternative  = 'greater')$p.value))
  print (c('high vs. control:',p,wilcox.test(x=dfs3$IndexPolII[dfs3$IndexK27_bin==p],y=dfs3$IndexPolII[dfs3$IndexK27_bin==10],alternative  = 'greater')$p.value))
  print (c('low vs. high:',p,wilcox.test(x=dfs3$IndexPolII[dfs3$IndexK27_bin==1],y=dfs3$IndexPolII[dfs3$IndexK27_bin==10],alternative  = 'greater')$p.value))
  ggsave(file=output,width=6,height=6)
  }
  
  

a=dfs$IndexK27
b=dfs1$IndexPolII
bin=100
step=20

i=1
k=1
k27<-vector()
PolII<-vector()
while ((i+bin)<length(a)){
  m=a[i:(i+bin)]
  n=b[i:(i+bin)]
  k27[k]=mean(m)
  PolII[k]=mean(n)
  i=i+step
  k=k+1
}

df2<-data.frame(k27,PolII)
names(df2)<-c("K27_I","PolII_I")

id="binned_point"

feature=paste(names(df2)[1],names(df2)[2],id,step,bin,sep=".")
ggplot(df2,aes(x=log2(K27_I),y=log2(PolII_I)))+
  geom_point(size=1)+
  theme_bw()+
  scale_x_continuous(limits = c(-3, 3))+
  scale_y_continuous(limits = c(3, 5))+
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        axis.text.y = element_text(size =rel(2) ),
        axis.text.x = element_text(size =rel(2)),
        axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        legend.title=element_blank(),
        legend.key = element_blank(),
        legend.position="top")
output=paste("Fig.3E","pdf",sep=".")
print (output)
ggsave(file=output,width=6,height=6)
corr <- cor.test(x=df2$K27_I, y=df2$PolII_I, method = 'spearman')
print(c('spearman',corr$estimate[[1]]))
print(c('spearman',corr$p.value[[1]]))
corr <- cor.test(x=df2$K27_I, y=df2$PolII_I, method = 'pearson')
print(c('pearson',corr$estimate[[1]]))
print(c('pearson',corr$p.value[[1]]))
}
}